==> haskell-case-insensitive-1.2.0.10-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.10
id: case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
key: case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: 4ee9561c1f3b5c7145d29fbe10dac765
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/case-insensitive-1.2.0.10
hs-libraries: HScase-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.10-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.10
id: case-insensitive-1.2.0.10-FRqGPugKcXCDhucdrD5I1k
key: case-insensitive-1.2.0.10-FRqGPugKcXCDhucdrD5I1k
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: f0039170ef1c6c371aeaa280843a460c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/case-insensitive-1.2.0.10
library-dirs: /usr/lib/ghc-8.0.2/site-local/case-insensitive-1.2.0.10
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/case-insensitive-1.2.0.10
hs-libraries: HScase-insensitive-1.2.0.10-FRqGPugKcXCDhucdrD5I1k
depends:
    base-4.9.1.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-3tyIJq2bWc6AwvrDmNvwy7
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
